@@ -1,23 +1,23 @@
 package DateTime::TimeZone::OlsonDB;
-$DateTime::TimeZone::OlsonDB::VERSION = '1.87';
+
 use strict;
 use warnings;
+use namespace::autoclean;
 
-use vars qw( %MONTHS %DAYS $PLUS_ONE_DAY_DUR $MINUS_ONE_DAY_DUR );
+our $VERSION = '2.11';
 
 use DateTime::TimeZone::OlsonDB::Rule;
 use DateTime::TimeZone::OlsonDB::Zone;
-use Params::Validate qw( validate SCALAR );
 
 my $x = 1;
-%MONTHS = map { $_ => $x++ } qw( Jan Feb Mar Apr May Jun
+our %MONTHS = map { $_ => $x++ } qw( Jan Feb Mar Apr May Jun
     Jul Aug Sep Oct Nov Dec);
 
 $x = 1;
-%DAYS = map { $_ => $x++ } qw( Mon Tue Wed Thu Fri Sat Sun );
+our %DAYS = map { $_ => $x++ } qw( Mon Tue Wed Thu Fri Sat Sun );
 
-$PLUS_ONE_DAY_DUR  = DateTime::Duration->new( days => 1 );
-$MINUS_ONE_DAY_DUR = DateTime::Duration->new( days => -1 );
+our $PLUS_ONE_DAY_DUR  = DateTime::Duration->new( days => 1 );
+our $MINUS_ONE_DAY_DUR = DateTime::Duration->new( days => -1 );
 
 sub new {
     my $class = shift;
@@ -40,6 +40,8 @@ sub parse_file {
         chomp;
         $self->_parse_line($_);
     }
+
+    close $fh or die $!;
 }
 
 sub _parse_line {
@@ -65,6 +67,7 @@ sub _parse_line {
     }
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _parse_rule {
     my $self = shift;
     my $rule = shift;
@@ -127,6 +130,7 @@ sub _parse_link {
 
     undef $self->{in_zone};
 }
+## use critic
 
 sub links { %{ $_[0]->{links} } }
 
@@ -148,15 +152,9 @@ sub zone {
 
 sub expanded_zone {
     my $self = shift;
-    my %p    = validate(
-        @_, {
-            name           => { type => SCALAR },
-            expand_to_year => {
-                type    => SCALAR,
-                default => (localtime)[5] + 1910
-            },
-        }
-    );
+    my %p    = @_;
+
+    $p{expand_to_year} ||= (localtime)[5] + 1910;
 
     my $zone = $self->zone( $p{name} );
 
@@ -228,16 +226,7 @@ sub parse_day_spec {
 }
 
 sub utc_datetime_for_time_spec {
-    my %p = validate(
-        @_, {
-            spec            => { type => SCALAR },
-            year            => { type => SCALAR },
-            month           => { type => SCALAR },
-            day             => { type => SCALAR },
-            offset_from_utc => { type => SCALAR },
-            offset_from_std => { type => SCALAR },
-        },
-    );
+    my %p = @_;
 
     # 'w'all - ignore it, because that's the default
     $p{spec} =~ s/w$//;
@@ -248,6 +237,7 @@ sub utc_datetime_for_time_spec {
     # 's'tandard time - ignore DS offset
     my $is_std = $p{spec} =~ s/s$//;
 
+    ## no critic (NamingConventions::ProhibitAmbiguousNames)
     my ( $hour, $minute, $second ) = split /:/, $p{spec};
     $minute = 0 unless defined $minute;
     $second = 0 unless defined $second;
@@ -302,13 +292,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::TimeZone::OlsonDB - An object to represent an Olson time zone database
 
 =head1 VERSION
 
-version 1.87
+version 2.11
 
 =head1 SYNOPSIS
 
@@ -341,15 +333,28 @@ that rule is in effect is "CST".
 
 Not yet documented.  This stuff is a mess.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-TimeZone/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-TimeZone can be found at L<https://github.com/houseabsolute/DateTime-TimeZone>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dave Rolsky.
+This software is copyright (c) 2017 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
